pub struct CacheSnapshot {
pub capacity: CacheCapacity,
pub resident_bytes: usize,
pub keys: usize,
pub ranges: usize,
pub hits: u64,
pub partial_hits: u64,
pub misses: u64,
pub insertions: u64,
pub admissions_rejected_too_large: u64,
pub evictions: u64,
}Expand description
A point-in-time cache state and statistics snapshot.
Fields
capacity: CacheCapacityConfigured capacity.
resident_bytes: usizeTotal resident payload bytes.
keys: usizeNumber of keys with resident ranges.
ranges: usizeNumber of resident ranges.
hits: u64Fully cached reads.
partial_hits: u64Reads with some, but not all, requested bytes cached.
misses: u64Reads with none of the requested bytes cached.
insertions: u64Successfully admitted insertions.
admissions_rejected_too_large: u64Insertions rejected because the merged range was too large.
evictions: u64Ranges removed by capacity enforcement.